# `BioClients.chem2bio2rdf`

## Chem2Bio2RDF

* <http://cheminfov.informatics.indiana.edu:8080/c2b2r/>
* <http://slapfordrugtargetprediction.wikispaces.com/API>

Chem2Bio2RDF employs a backend PostgreSql db. This
BioClients API provides
programmatic access to an available db instance, which available
locally (e.g. within IU intranet), or may be available via download
and mirror instance.

### Database credentials

Db credentials are normally stored in a configuration file at
`$HOME/.c2b2r.yaml`.
